@@ -54,3 +54,8 @@ def get():
 		stop.name = row[1]
 		stops.append(stop)
 	return stops
+
+def is_favorite(stop):
+	# Determine whether a stop is a favorite or not
+	fav = get()
+	return len([s for s in fav if s.id == stop.id]) > 0
